@@ -161,9 +161,9 @@ sub style_text {
     my $text_nodes = $self->find_text_nodes($regex, delete $options{exclude_tables});
 
     for my $text_node (@$text_nodes) {
-        my ($run_props) = $self->xpc->findnodes('../../w:rPr', $text_node);
+        my ($run_props) = $self->xpc->findnodes('ancestor::w:r[1]/w:rPr', $text_node);
         if (!$run_props) {
-            my ($run) = $self->xpc->findnodes('../w:r', $text_node);
+            my ($run) = $self->xpc->findnodes('ancestor::w:r[1]', $text_node);
             $run_props = $run->addNewChild($run->namespaceURI => 'rPr');
         }
 
@@ -438,7 +438,7 @@ Document::OOXML::Part::WordprocessingML - WordprocessingML document part handlin
 
 =head1 VERSION
 
-version 0.180740
+version 0.180741
 
 =head1 ATTRIBUTES
 
@@ -560,7 +560,7 @@ Martijn van de Streek <martijn@vandestreek.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Martijn van de Streek.
+This software is copyright (c) 2018 by Martijn van de Streek.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
